@@ -35,7 +35,9 @@ spec:
         kubernetes.io/os: linux
       priorityClassName: system-cluster-critical
       tolerations:
-      - operator: Exists
+      - effect: NoSchedule
+        key: node-role.kubernetes.io/master
+        operator: Exists
       serviceAccountName: node-ca
       containers:
       - name: node-ca
