@@ -118,9 +118,10 @@ func (d *driver) getS3Service() (*s3.S3, error) {
 
 	// A custom HTTPClient is used here since the default HTTPClients ProxyFromEnvironment
 	// uses a cache which won't let us update the proxy env vars
-	awsConfig := &aws.Config{
+	sess, err := session.NewSession(&aws.Config{
 		Credentials: credentials.NewStaticCredentials(cfg.AccessKey, cfg.SecretKey, ""),
 		Region:      &d.Config.Region,
+		Endpoint:    &d.Config.RegionEndpoint,
 		HTTPClient: &http.Client{
 			Transport: &http.Transport{
 				Proxy: func(req *http.Request) (*url.URL, error) {
@@ -128,12 +129,7 @@ func (d *driver) getS3Service() (*s3.S3, error) {
 				},
 			},
 		},
-	}
-	if d.Config.RegionEndpoint != "" {
-		awsConfig.WithS3ForcePathStyle(true)
-		awsConfig.WithEndpoint(d.Config.RegionEndpoint)
-	}
-	sess, err := session.NewSession(awsConfig)
+	})
 	if err != nil {
 		return nil, err
 	}
@@ -623,3 +619,8 @@ func (d *driver) RemoveStorage(cr *imageregistryv1.Config) (bool, error) {
 
 	return false, nil
 }
+
+// ID return the underlying storage identificator, on this case the bucket name.
+func (d *driver) ID() string {
+	return d.Config.Bucket
+}
